@@ -193,9 +193,9 @@ class IPInsightsPredictor(Predictor):
         serializer=CSVSerializer(),
         deserializer=JSONDeserializer(),
     ):
-        """
-        Args:
+        """Creates object to be used to get dot product of entity nad IP address.
 
+        Args:
             endpoint_name (str): Name of the Amazon SageMaker endpoint to which
                 requests are sent.
             sagemaker_session (sagemaker.session.Session): A SageMaker Session
@@ -223,9 +223,9 @@ class IPInsightsModel(Model):
     """
 
     def __init__(self, model_data, role, sagemaker_session=None, **kwargs):
-        """
-        Args:
+        """Creates object to get insights on S3 model data.
 
+        Args:
             model_data (str): The S3 location of a SageMaker model data
                 ``.tar.gz`` file.
             role (str): An AWS IAM role (either name or full ARN). The Amazon
