@@ -152,7 +152,7 @@ class IngestionManagerPandas:
         feature_group_name (str): name of the Feature Group.
         sagemaker_session (Session): instance of the Session class to perform boto calls.
         data_frame (DataFrame): pandas DataFrame to be ingested to the given feature group.
-        max_works (int): number of threads to create.
+        max_workers (int): number of threads to create.
     """
 
     feature_group_name: str = attr.ib()
@@ -290,7 +290,7 @@ class FeatureGroup:
 
     def create(
         self,
-        s3_uri: str,
+        s3_uri: Union[str, bool],
         record_identifier_name: str,
         event_time_feature_name: str,
         role_arn: str,
@@ -305,7 +305,8 @@ class FeatureGroup:
         """Create a SageMaker FeatureStore FeatureGroup.
 
         Args:
-            s3_uri (str): S3 URI of the offline store.
+            s3_uri (Union[str, bool]): S3 URI of the offline store, set to
+                ``False`` to disable offline store.
             record_identifier_name (str): name of the record identifier feature.
             event_time_feature_name (str): name of the event time feature.
             role_arn (str): ARN of the role used to call CreateFeatureGroup.
@@ -342,15 +343,18 @@ class FeatureGroup:
             create_feature_store_args.update({"online_store_config": online_store_config.to_dict()})
 
         # offline store configuration
-        s3_storage_config = S3StorageConfig(s3_uri=s3_uri)
-        if offline_store_kms_key_id:
-            s3_storage_config.kms_key_id = offline_store_kms_key_id
-        offline_store_config = OfflineStoreConfig(
-            s3_storage_config=s3_storage_config,
-            disable_glue_table_creation=disable_glue_table_creation,
-            data_catalog_config=data_catalog_config,
-        )
-        create_feature_store_args.update({"offline_store_config": offline_store_config.to_dict()})
+        if s3_uri:
+            s3_storage_config = S3StorageConfig(s3_uri=s3_uri)
+            if offline_store_kms_key_id:
+                s3_storage_config.kms_key_id = offline_store_kms_key_id
+            offline_store_config = OfflineStoreConfig(
+                s3_storage_config=s3_storage_config,
+                disable_glue_table_creation=disable_glue_table_creation,
+                data_catalog_config=data_catalog_config,
+            )
+            create_feature_store_args.update(
+                {"offline_store_config": offline_store_config.to_dict()}
+            )
 
         return self.sagemaker_session.create_feature_group(**create_feature_store_args)
 
@@ -367,7 +371,9 @@ class FeatureGroup:
         Returns:
             Response dict from the service.
         """
-        return self.sagemaker_session.describe_feature_group(self.name, next_token)
+        return self.sagemaker_session.describe_feature_group(
+            feature_group_name=self.name, next_token=next_token
+        )
 
     def load_feature_definitions(
         self,
@@ -502,6 +508,9 @@ class FeatureGroup:
                 f"  {definition.feature_name} "
                 f"{self._FEATURE_TYPE_TO_DDL_DATA_TYPE_MAP.get(definition.feature_type.value)}\n"
             )
+        ddl += "  write_time TIMESTAMP\n"
+        ddl += "  event_time TIMESTAMP\n"
+        ddl += "  is_deleted BOOLEAN\n"
         ddl += ")\n"
         ddl += (
             "ROW FORMAT SERDE 'org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe'\n"
