@@ -469,9 +469,12 @@ class _SageMakerContainer(object):
 
         volumes.append(_Volume(model_dir, "/opt/ml/model"))
 
-        # Mount the metadata directory on the notebook instance,
-        # this is used by some DeepEngine libraries
-        volumes.append(_Volume("/opt/ml/metadata", "/opt/ml/metadata"))
+        # Mount the metadata directory if present.
+        # Only expected to be present on SM notebook instances.
+        # This is used by some DeepEngine libraries
+        metadata_dir = "/opt/ml/metadata"
+        if os.path.isdir(metadata_dir):
+            volumes.append(_Volume(metadata_dir, metadata_dir))
 
         # Set up the channels for the containers. For local data we will
         # mount the local directory to the container. For S3 Data we will download the S3 data
@@ -1064,7 +1067,7 @@ def _ecr_login_if_needed(boto_session, image):
     ecr_url = auth["authorizationData"][0]["proxyEndpoint"]
 
     cmd = "docker login -u AWS -p %s %s" % (token, ecr_url)
-    subprocess.check_output(cmd, shell=True)
+    subprocess.check_output(cmd.split())
 
     return True
 
@@ -1078,5 +1081,5 @@ def _pull_image(image):
     pull_image_command = ("docker pull %s" % image).strip()
     logger.info("docker command: %s", pull_image_command)
 
-    subprocess.check_output(pull_image_command, shell=True)
+    subprocess.check_output(pull_image_command.split())
     logger.info("image pulled: %s", image)
