@@ -40,7 +40,13 @@ class MXNetPredictor(Predictor):
     multidimensional tensors for MXNet inference.
     """
 
-    def __init__(self, endpoint_name, sagemaker_session=None):
+    def __init__(
+        self,
+        endpoint_name,
+        sagemaker_session=None,
+        serializer=JSONSerializer(),
+        deserializer=JSONDeserializer(),
+    ):
         """Initialize an ``MXNetPredictor``.
 
         Args:
@@ -50,9 +56,16 @@ class MXNetPredictor(Predictor):
                 manages interactions with Amazon SageMaker APIs and any other
                 AWS services needed. If not specified, the estimator creates one
                 using the default AWS configuration chain.
+            serializer (callable): Optional. Default serializes input data to
+                json. Handles dicts, lists, and numpy arrays.
+            deserializer (callable): Optional. Default parses the response using
+                ``json.load(...)``.
         """
         super(MXNetPredictor, self).__init__(
-            endpoint_name, sagemaker_session, JSONSerializer(), JSONDeserializer()
+            endpoint_name,
+            sagemaker_session,
+            serializer=serializer,
+            deserializer=deserializer,
         )
 
 
@@ -198,8 +211,9 @@ class MXNetModel(FrameworkModel):
         )
 
     def prepare_container_def(self, instance_type=None, accelerator_type=None):
-        """Return a container definition with framework configuration set in
-        model environment variables.
+        """Return a container definition with framework configuration.
+
+        Framework configuration is set in model environment variables.
 
         Args:
             instance_type (str): The EC2 instance type to deploy this Model to.
@@ -261,8 +275,9 @@ class MXNetModel(FrameworkModel):
         )
 
     def _is_mms_version(self):
-        """Whether the framework version corresponds to an inference image using
-        the Multi-Model Server (https://github.com/awslabs/multi-model-server).
+        """Whether the framework version corresponds to an inference image using the MMS.
+
+        MMS Server: (https://github.com/awslabs/multi-model-server).
 
         Returns:
             bool: If the framework version corresponds to an image using MMS.
